==> eam-wshub-proxyclient-11.5-4-sources.jar: net/datastream/schemas/mp_entities/positionequipment_001/PositionChildHierarchy.java <==

package net.datastream.schemas.mp_entities.positionequipment_001;

import java.util.ArrayList;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_entities.assetequipment_001.ChildAsset;
import net.datastream.schemas.mp_fields.EQUIPMENTID_Type;
import net.datastream.schemas.mp_fields.TYPE_Type;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}POSITIONID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TYPE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_entities/PositionEquipment_001}ChildPosition" maxOccurs="unbounded" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_entities/AssetEquipment_001}ChildAsset" maxOccurs="unbounded" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "positionid",
    "type",
    "childPosition",
    "childAsset"
})
@XmlRootElement(name = "PositionChildHierarchy")
public class PositionChildHierarchy {

    @XmlElement(name = "POSITIONID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected EQUIPMENTID_Type positionid;
    @XmlElement(name = "TYPE", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected TYPE_Type type;
    @XmlElement(name = "ChildPosition")
    protected List<ChildPosition> childPosition;
    @XmlElement(name = "ChildAsset", namespace = "http://schemas.datastream.net/MP_entities/AssetEquipment_001")
    protected List<ChildAsset> childAsset;

    /**
     * Obtient la valeur de la propriété positionid.
     * 
     * @return
     *     possible object is
     *     {@link EQUIPMENTID_Type }
     *     
     */
    public EQUIPMENTID_Type getPOSITIONID() {
        return positionid;
    }

    /**
     * Définit la valeur de la propriété positionid.
     * 
     * @param value
     *     allowed object is
     *     {@link EQUIPMENTID_Type }
     *     
     */
    public void setPOSITIONID(EQUIPMENTID_Type value) {
        this.positionid = value;
    }

    /**
     * Obtient la valeur de la propriété type.
     * 
     * @return
     *     possible object is
     *     {@link TYPE_Type }
     *     
     */
    public TYPE_Type getTYPE() {
        return type;
    }

    /**
     * Définit la valeur de la propriété type.
     * 
     * @param value
     *     allowed object is
     *     {@link TYPE_Type }
     *     
     */
    public void setTYPE(TYPE_Type value) {
        this.type = value;
    }

    /**
     * Gets the value of the childPosition property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the childPosition property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getChildPosition().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link ChildPosition }
     * 
     * 
     */
    public List<ChildPosition> getChildPosition() {
        if (childPosition == null) {
            childPosition = new ArrayList<ChildPosition>();
        }
        return this.childPosition;
    }

    /**
     * Gets the value of the childAsset property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the childAsset property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getChildAsset().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link ChildAsset }
     * 
     * 
     */
    public List<ChildAsset> getChildAsset() {
        if (childAsset == null) {
            childAsset = new ArrayList<ChildAsset>();
        }
        return this.childAsset;
    }

}

==> eam-wshub-proxyclient-12.1.0-21-sources.jar: net/datastream/schemas/mp_entities/positionequipment_001/PositionChildHierarchy.java <==

package net.datastream.schemas.mp_entities.positionequipment_001;

import java.util.ArrayList;
import java.util.List;
import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlElement;
import jakarta.xml.bind.annotation.XmlRootElement;
import jakarta.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_entities.assetequipment_001.ChildAsset;
import net.datastream.schemas.mp_fields.EQUIPMENTID_Type;
import net.datastream.schemas.mp_fields.TYPE_Type;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>{@code
 * <complexType>
 *   <complexContent>
 *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       <sequence>
 *         <element ref="{http://schemas.datastream.net/MP_fields}POSITIONID"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}TYPE"/>
 *         <element ref="{http://schemas.datastream.net/MP_entities/PositionEquipment_001}ChildPosition" maxOccurs="unbounded" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_entities/AssetEquipment_001}ChildAsset" maxOccurs="unbounded" minOccurs="0"/>
 *       </sequence>
 *     </restriction>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "positionid",
    "type",
    "childPosition",
    "childAsset"
})
@XmlRootElement(name = "PositionChildHierarchy")
public class PositionChildHierarchy {

    @XmlElement(name = "POSITIONID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected EQUIPMENTID_Type positionid;
    @XmlElement(name = "TYPE", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected TYPE_Type type;
    @XmlElement(name = "ChildPosition")
    protected List<ChildPosition> childPosition;
    @XmlElement(name = "ChildAsset", namespace = "http://schemas.datastream.net/MP_entities/AssetEquipment_001")
    protected List<ChildAsset> childAsset;

    /**
     * Gets the value of the positionid property.
     * 
     * @return
     *     possible object is
     *     {@link EQUIPMENTID_Type }
     *     
     */
    public EQUIPMENTID_Type getPOSITIONID() {
        return positionid;
    }

    /**
     * Sets the value of the positionid property.
     * 
     * @param value
     *     allowed object is
     *     {@link EQUIPMENTID_Type }
     *     
     */
    public void setPOSITIONID(EQUIPMENTID_Type value) {
        this.positionid = value;
    }

    /**
     * Gets the value of the type property.
     * 
     * @return
     *     possible object is
     *     {@link TYPE_Type }
     *     
     */
    public TYPE_Type getTYPE() {
        return type;
    }

    /**
     * Sets the value of the type property.
     * 
     * @param value
     *     allowed object is
     *     {@link TYPE_Type }
     *     
     */
    public void setTYPE(TYPE_Type value) {
        this.type = value;
    }

    /**
     * Gets the value of the childPosition property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the Jakarta XML Binding object.
     * This is why there is not a {@code set} method for the childPosition property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getChildPosition().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link ChildPosition }
     * 
     * 
     * @return
     *     The value of the childPosition property.
     */
    public List<ChildPosition> getChildPosition() {
        if (childPosition == null) {
            childPosition = new ArrayList<>();
        }
        return this.childPosition;
    }

    /**
     * Gets the value of the childAsset property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the Jakarta XML Binding object.
     * This is why there is not a {@code set} method for the childAsset property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getChildAsset().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link ChildAsset }
     * 
     * 
     * @return
     *     The value of the childAsset property.
     */
    public List<ChildAsset> getChildAsset() {
        if (childAsset == null) {
            childAsset = new ArrayList<>();
        }
        return this.childAsset;
    }

}
